==> staffology-0.1.1-py3-none-any.whl: staffology/api/billing/direct_debit_mandate_billing.py <==
from typing import Any, Dict, Optional

import httpx

from ...client import Client
from ...models.direct_debit_mandate import DirectDebitMandate
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/billing/directdebit".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[DirectDebitMandate]:
    if response.status_code == 200:
        response_200 = DirectDebitMandate.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[DirectDebitMandate]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
) -> Response[DirectDebitMandate]:
    """Get DirectDebitMandate

     Returns the DirectDebitMandate for the authenticated account

    Returns:
        Response[DirectDebitMandate]
    """

    kwargs = _get_kwargs(
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
) -> Optional[DirectDebitMandate]:
    """Get DirectDebitMandate

     Returns the DirectDebitMandate for the authenticated account

    Returns:
        Response[DirectDebitMandate]
    """

    return sync_detailed(
        client=client,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
) -> Response[DirectDebitMandate]:
    """Get DirectDebitMandate

     Returns the DirectDebitMandate for the authenticated account

    Returns:
        Response[DirectDebitMandate]
    """

    kwargs = _get_kwargs(
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
) -> Optional[DirectDebitMandate]:
    """Get DirectDebitMandate

     Returns the DirectDebitMandate for the authenticated account

    Returns:
        Response[DirectDebitMandate]
    """

    return (
        await asyncio_detailed(
            client=client,
        )
    ).parsed

==> staffology-0.1.7-py3-none-any.whl: staffology/api/billing/direct_debit_mandate_billing.py <==
from typing import Any, Dict, Optional

import httpx
from staffology.propagate_exceptions import raise_staffology_exception

from ...client import Client
from ...models.direct_debit_mandate import DirectDebitMandate
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/billing/directdebit".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[DirectDebitMandate]:
    if response.status_code == 200:
        response_200 = DirectDebitMandate.from_dict(response.json())

        return response_200
    return raise_staffology_exception(response)


def _build_response(*, response: httpx.Response) -> Response[DirectDebitMandate]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
) -> Response[DirectDebitMandate]:
    """Get DirectDebitMandate

     Returns the DirectDebitMandate for the authenticated account

    Returns:
        Response[DirectDebitMandate]
    """

    kwargs = _get_kwargs(
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
) -> Optional[DirectDebitMandate]:
    """Get DirectDebitMandate

     Returns the DirectDebitMandate for the authenticated account

    Returns:
        Response[DirectDebitMandate]
    """

    return sync_detailed(
        client=client,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
) -> Response[DirectDebitMandate]:
    """Get DirectDebitMandate

     Returns the DirectDebitMandate for the authenticated account

    Returns:
        Response[DirectDebitMandate]
    """

    kwargs = _get_kwargs(
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
) -> Optional[DirectDebitMandate]:
    """Get DirectDebitMandate

     Returns the DirectDebitMandate for the authenticated account

    Returns:
        Response[DirectDebitMandate]
    """

    return (
        await asyncio_detailed(
            client=client,
        )
    ).parsed
